@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -658,9 +644,9 @@ static void sim_fs_op_cache_fileinfo(struct sim_fs *fs,
 	fileinfo[5] = record_length & 0xff;
 	fileinfo[6] = file_status;
 
-	path = g_strdup_printf(SIM_CACHE_PATH, imsi, phase, op->id);
+	path = l_strdup_printf(SIM_CACHE_PATH, imsi, phase, op->id);
 	fs->fd = L_TFR(open(path, O_WRONLY | O_CREAT | O_TRUNC, SIM_CACHE_MODE));
-	g_free(path);
+	l_free(path);
 
 	if (fs->fd == -1)
 		return;
@@ -755,13 +741,9 @@ static gboolean sim_fs_op_check_cached(struct sim_fs *fs)
 	if (imsi == NULL || phase == OFONO_SIM_PHASE_UNKNOWN)
 		return FALSE;
 
-	path = g_strdup_printf(SIM_CACHE_PATH, imsi, phase, op->id);
-
-	if (path == NULL)
-		return FALSE;
-
+	path = l_strdup_printf(SIM_CACHE_PATH, imsi, phase, op->id);
 	fd = L_TFR(open(path, O_RDWR));
-	g_free(path);
+	l_free(path);
 
 	if (fd == -1) {
 		if (errno != ENOENT)
@@ -1158,8 +1140,7 @@ void sim_fs_cache_image(struct sim_fs *fs, const char *image, int id)
 		return;
 
 	write_file((const unsigned char *) image, strlen(image),
-			SIM_CACHE_MODE, SIM_IMAGE_CACHE_PATH, imsi,
-			phase, id);
+			SIM_IMAGE_CACHE_PATH, imsi, phase, id);
 }
 
 char *sim_fs_get_cached_image(struct sim_fs *fs, int id)
@@ -1184,11 +1165,11 @@ char *sim_fs_get_cached_image(struct sim_fs *fs, int id)
 	if (phase == OFONO_SIM_PHASE_UNKNOWN)
 		return NULL;
 
-	path = g_strdup_printf(SIM_IMAGE_CACHE_PATH, imsi, phase, id);
+	path = l_strdup_printf(SIM_IMAGE_CACHE_PATH, imsi, phase, id);
 
 	L_TFR(stat(path, &st_buf));
 	fd = L_TFR(open(path, O_RDONLY));
-	g_free(path);
+	l_free(path);
 
 	if (fd < 0)
 		return NULL;
@@ -1224,9 +1205,9 @@ static void remove_cachefile(const char *imsi, enum ofono_sim_phase phase,
 	if (sscanf(file->d_name, "%4x", &id) != 1)
 		return;
 
-	path = g_strdup_printf(SIM_CACHE_PATH, imsi, phase, id);
+	path = l_strdup_printf(SIM_CACHE_PATH, imsi, phase, id);
 	remove(path);
-	g_free(path);
+	l_free(path);
 }
 
 static void remove_imagefile(const char *imsi, enum ofono_sim_phase phase,
@@ -1241,9 +1222,9 @@ static void remove_imagefile(const char *imsi, enum ofono_sim_phase phase,
 	if (sscanf(file->d_name, "%d", &id) != 1)
 		return;
 
-	path = g_strdup_printf(SIM_IMAGE_CACHE_PATH, imsi, phase, id);
+	path = l_strdup_printf(SIM_IMAGE_CACHE_PATH, imsi, phase, id);
 	remove(path);
-	g_free(path);
+	l_free(path);
 }
 
 void sim_fs_check_version(struct sim_fs *fs)
@@ -1262,27 +1243,27 @@ void sim_fs_check_version(struct sim_fs *fs)
 	sim_fs_cache_flush(fs);
 
 	version = SIM_FS_VERSION;
-	write_file(&version, 1, SIM_CACHE_MODE, SIM_CACHE_VERSION, imsi, phase);
+	write_file(&version, 1, SIM_CACHE_VERSION, imsi, phase);
 }
 
 void sim_fs_cache_flush(struct sim_fs *fs)
 {
 	const char *imsi = ofono_sim_get_imsi(fs->sim);
 	enum ofono_sim_phase phase = ofono_sim_get_phase(fs->sim);
-	char *path = g_strdup_printf(SIM_CACHE_BASEPATH, imsi, phase);
+	char *path = l_strdup_printf(SIM_CACHE_BASEPATH, imsi, phase);
 	struct dirent **entries;
 	int len = scandir(path, &entries, NULL, alphasort);
 
-	g_free(path);
+	l_free(path);
 
 	if (len > 0) {
 		/* Remove all file ids */
 		while (len--) {
 			remove_cachefile(imsi, phase, entries[len]);
-			g_free(entries[len]);
+			free(entries[len]);
 		}
 
-		g_free(entries);
+		free(entries);
 	}
 
 	sim_fs_image_cache_flush(fs);
@@ -1292,21 +1273,21 @@ void sim_fs_cache_flush_file(struct sim_fs *fs, int id)
 {
 	const char *imsi = ofono_sim_get_imsi(fs->sim);
 	enum ofono_sim_phase phase = ofono_sim_get_phase(fs->sim);
-	char *path = g_strdup_printf(SIM_CACHE_PATH, imsi, phase, id);
+	char *path = l_strdup_printf(SIM_CACHE_PATH, imsi, phase, id);
 
 	remove(path);
-	g_free(path);
+	l_free(path);
 }
 
 void sim_fs_image_cache_flush(struct sim_fs *fs)
 {
 	const char *imsi = ofono_sim_get_imsi(fs->sim);
 	enum ofono_sim_phase phase = ofono_sim_get_phase(fs->sim);
-	char *path = g_strdup_printf(SIM_IMAGE_CACHE_BASEPATH, imsi, phase);
+	char *path = l_strdup_printf(SIM_IMAGE_CACHE_BASEPATH, imsi, phase);
 	struct dirent **entries;
 	int len = scandir(path, &entries, NULL, alphasort);
 
-	g_free(path);
+	l_free(path);
 
 	if (len <= 0)
 		return;
@@ -1314,18 +1295,18 @@ void sim_fs_image_cache_flush(struct sim_fs *fs)
 	/* Remove everything */
 	while (len--) {
 		remove_imagefile(imsi, phase, entries[len]);
-		g_free(entries[len]);
+		free(entries[len]);
 	}
 
-	g_free(entries);
+	free(entries);
 }
 
 void sim_fs_image_cache_flush_file(struct sim_fs *fs, int id)
 {
 	const char *imsi = ofono_sim_get_imsi(fs->sim);
 	enum ofono_sim_phase phase = ofono_sim_get_phase(fs->sim);
-	char *path = g_strdup_printf(SIM_IMAGE_CACHE_PATH, imsi, phase, id);
+	char *path = l_strdup_printf(SIM_IMAGE_CACHE_PATH, imsi, phase, id);
 
 	remove(path);
-	g_free(path);
+	l_free(path);
 }
